Chapter 1: Galaxies
===================

In chapter 1, we introduce you to galaxy morphology, structure and the core **PyAutoGalaxy** API.

**Binder** links to every tutorial are included.

The chapter contains the following tutorials:

`Tutorial 0: Visualization <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_0_visualization.ipynb>`_
- Setting up **PyAutoGalaxy**'s visualization library.

`Tutorial 1: Grids <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_1_grids.ipynb>`_
- Uniform grids of (y,x) coordinates used for ray-tracing.

`Tutorial 2: Light Profiles <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_2_light_profiles.ipynb>`_
- Analytic profiles representing light distributions.

`Tutorial 3: Galaxies <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_3_galaxies.ipynb>`_
- Making galaxy objects out of light and mass profile.

`Tutorial 6: Summary <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_1_introduction/tutorial_6_summary.ipynb>`_
- A summary of the chapter.